@@ -45,7 +45,7 @@ Displays detailed information about where a package is referenced.
 
 <info>php composer.phar depends composer/composer</info>
 
-Read more at https://getcomposer.org/doc/03-cli.md#depends-why-
+Read more at https://getcomposer.org/doc/03-cli.md#depends-why
 EOT
             )
         ;
