@@ -94,6 +94,7 @@ class GitHubDriverTest extends TestCase
         $this->assertEquals('test_master', $gitHubDriver->getRootIdentifier());
 
         $dist = $gitHubDriver->getDist($sha);
+        self::assertIsArray($dist);
         $this->assertEquals('zip', $dist['type']);
         $this->assertEquals('https://api.github.com/repos/composer/packagist/zipball/SOMESHA', $dist['url']);
         $this->assertEquals('SOMESHA', $dist['reference']);
@@ -136,6 +137,7 @@ class GitHubDriverTest extends TestCase
         $this->assertEquals('test_master', $gitHubDriver->getRootIdentifier());
 
         $dist = $gitHubDriver->getDist($sha);
+        self::assertIsArray($dist);
         $this->assertEquals('zip', $dist['type']);
         $this->assertEquals('https://api.github.com/repos/composer/packagist/zipball/SOMESHA', $dist['url']);
         $this->assertEquals($sha, $dist['reference']);
@@ -181,6 +183,7 @@ class GitHubDriverTest extends TestCase
         $this->assertEquals('test_master', $gitHubDriver->getRootIdentifier());
 
         $dist = $gitHubDriver->getDist($sha);
+        self::assertIsArray($dist);
         $this->assertEquals('zip', $dist['type']);
         $this->assertEquals('https://api.github.com/repos/composer/packagist/zipball/SOMESHA', $dist['url']);
         $this->assertEquals($sha, $dist['reference']);
@@ -288,6 +291,7 @@ class GitHubDriverTest extends TestCase
         $this->assertEquals('test_master', $gitHubDriver->getRootIdentifier());
 
         $dist = $gitHubDriver->getDist($sha);
+        self::assertIsArray($dist);
         $this->assertEquals('zip', $dist['type']);
         $this->assertEquals('https://api.github.com/repos/composer/packagist/zipball/SOMESHA', $dist['url']);
         $this->assertEquals($sha, $dist['reference']);
@@ -326,7 +330,7 @@ class GitHubDriverTest extends TestCase
     /**
      * @return list<array{string}>
      */
-    public function invalidUrlProvider()
+    public static function invalidUrlProvider()
     {
         return [
             ['https://github.com/acme'],
@@ -348,7 +352,7 @@ class GitHubDriverTest extends TestCase
     /**
      * @return list<array{bool, string}>
      */
-    public function supportsProvider(): array
+    public static function supportsProvider(): array
     {
         return [
             [false, 'https://github.com/acme'],
